import { DeepClient, SerialOperation } from '@deep-foundation/deeplinks/imports/client';
import { MotionInfo } from './motion-info';
/**
  * Gets serial operations to insert Motion
  *
  * @example
 ```ts
 const serialOperations = await getMotionInsertSerialOperations({
   deep,
   info
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export declare function getMotionInsertSerialOperations(param: GetMotionInsertSerialOperationsParam): Promise<Array<SerialOperation>>;
export interface GetMotionInsertSerialOperationsParam {
    /**
     * Reserved link ids that will be used in the serial operations
     */
    reservedLinkIds?: {
        /**
         * Reserved link id for the motion
         */
        motionLinkId: number;
        /**
         * Reserved link id for the contain
         */
        containLinkId: number;
    };
    /**
     * Link ids of types that will be used in the serial operations
     */
    typeLinkIds?: {
        /**
         * Link id of the contain type
         */
        containTypeLinkId?: number;
        /**
         * Link id of the motion type
         */
        motionTypeLinkId?: number;
    };
    /**
     * Deep Client
     */
    deep: DeepClient;
    /**
     * Motion Info
     */
    info: MotionInfo;
    /**
     * Link id of the container
     *
     * @remarks
     * If it is null, contain link will not be created
     *
     * @defaultValue {@link GetMotionInsertSerialOperationsParam.deep.linkId} if it is undefined or not provided
     */
    containerLinkId?: number | undefined | null;
    /**
     * Value of the contain link
     *
     * @remarks
     * If {@link GetMotionInsertSerialOperationsParam.containerLinkId} is null, this will be ignored
     */
    containValue?: string | undefined;
}
