import { DeepClient, SerialOperation } from '@deep-foundation/deeplinks/imports/client.js';
import { Link } from '@deep-foundation/deeplinks/imports/minilinks.js';
import { MotionInfo } from './motion-info.js';
/**
   * Updates value of {@link GetMotionValueUpdateSerialOperationsParam.motionLink} or {@link GetMotionValueUpdateSerialOperationsParam.motionLinkId} to {@link GetMotionValueUpdateSerialOperationsParam.info}
   *
   * @remarks
   * After update, the [`UpdateHandler`](https://freephoenix888.github.io/object-to-links-async-converter/classes/Package.html#UpdateHandler) will create links to represent the value
   *
   * @throws if neither {@link motionLink} nor {@link motionLinkId} is passed
   * @throws if {@link motionLinkId} is passed but it does not exist
   * @throws if both {@link motionLink} and {@link motionLinkId} are passed
   *
   * @example
   * #### Save Motion Info
```ts
let info = {
  acceleration: {
    x: 3.2,
    y: 4.7,
    z: -9.8,
  },
  accelerationIncludingGravity: {
    x: 0.3,
    y: 0.2,
    z: -9.8,
  },
  rotationRate: {
    alpha: 30,
    beta: 60,
    gamma: 90,
  },
  interval: 1000,
};

const serialOperations = await getMotionValueUpdateSerialOperations({
  deep,
  info,
  motionLinkId
});

await deep.serial({
  operations: serialOperations
})
```
   */
export declare function getMotionValueUpdateSerialOperations(param: GetMotionValueUpdateSerialOperationsParam): Promise<Array<SerialOperation>>;
export type GetMotionValueUpdateSerialOperationsParam = {
    deep: DeepClient;
    info: Partial<MotionInfo>;
} & ({
    motionLinkId: number;
} | {
    motionLink: Link<number>;
});
